pub fn get_header(
name: &str,
headers: &[(ByteString, ByteString)],
) -> Option<ByteString>Expand description
Get value for the header with the given name.
pub fn get_header(
name: &str,
headers: &[(ByteString, ByteString)],
) -> Option<ByteString>Get value for the header with the given name.