LscBackend

Struct LscBackend 

pub struct LscBackend { /* private fields */ }

Implementations

Source

impl LscBackend

pub fn set_shard(&self, shard: Rc<CacheShard>)

Source

impl LscBackend

pub async fn storage_open(&self, cache_name: String) -> Result<i64, CacheError>

Open a cache storage. Internally, this allocates an id and maps it to the provided cache name.

pub async fn storage_has(&self, _cache_name: String) -> Result<bool, CacheError>

Check if a cache with the provided name exists. Always returns true.

pub async fn storage_delete( &self, _cache_name: String, ) -> Result<bool, CacheError>

Delete a cache storage. Not yet implemented.

pub async fn put( &self, request_response: CachePutRequest, resource: Option<Rc<dyn Resource>>, ) -> Result<(), CacheError>

Writes an entry to the cache.

pub async fn match( &self, request: CacheMatchRequest, ) -> Result<Option<(CacheMatchResponseMeta, Option<CacheResponseResource>)>, CacheError>

Matches a request against the cache.

pub async fn delete( &self, request: CacheDeleteRequest, ) -> Result<bool, CacheError>